![](logo.png)

Tools for Air Quality Data Analysis 


Description
===========
Python Library to better understand the air quaility data through visualizations.


# Installation
```
pip install vayu
```

# Sample Usage
For sample usage please look at the jupyer notebooks in the examples folder.
